@@ -211,10 +211,11 @@
  */
 - (void)copyFileToNJB:(NSString *)filename
 {
-	Track *track = [[Track alloc] init];
-	[track setFullPath:filename];
+	ID3Tagger *tagger = [[ID3Tagger alloc] init];
+	[tagger setFilename:filename];
+	Track *track = [tagger readTrack];
 	[self copyTrackToNJB:track];
-	[track release];
+	[tagger release];
 }
 
 /* actually add the track to the queue
