@@ -65,6 +65,8 @@ StatusDisplayer *statusDisplayerGlobal;
 		downloadingFiles = NO;
 		
 		supportedFiletypes = NULL;
+		
+		device = NULL;
 	}
 	return self;
 }
@@ -215,8 +217,6 @@ StatusDisplayer *statusDisplayerGlobal;
 	if (debug)
 		NJB_Set_Debug(debug);
 	
-	[self setStatus:STATUS_CONNECTING];
-	
 	if (NJB_Discover(njbs, 0, &n) == -1)
 	{
 		//[self setStatus:STATUS_NO_NJB];
@@ -1128,15 +1128,16 @@ StatusDisplayer *statusDisplayerGlobal;
 	}
 	else
 	{
-		char *storage_description = NULL;
-		char *volume_label = NULL;
-		if (LIBMTP_Get_Storageinfo(device, &totalDiskSpace, &freeDiskSpace, &storage_description, &volume_label) == 0)
-		{
-			free(storage_description);
-			free(volume_label);
-			
-			[statusDisplayer updateDiskSpace:totalDiskSpace withFreeSpace:freeDiskSpace];
-		}
+		if (device == NULL || LIBMTP_Get_Storage(device, 0) == -1)
+			return;
+		
+		if (device->storage == NULL)
+			return;
+		
+		totalDiskSpace = device->storage[0].MaxCapacity;
+		freeDiskSpace = device->storage[0].FreeSpaceInBytes;
+		
+		[statusDisplayer updateDiskSpace:totalDiskSpace withFreeSpace:freeDiskSpace];
 	}
 }
 
