@@ -10,9 +10,13 @@
 
 @interface NJBTransactionResult : NSObject {
 	BOOL success;
+	NSString *resultString;
 }
 - (id)initWithSuccess:(BOOL)newSuccess;
+- (id)initWithSuccess:(BOOL)newSuccess resultString:(NSString *)newResultString;
 - (void)setSuccess:(BOOL)newSuccess;
 - (BOOL)success;
+- (void)setResultString:(NSString *)newResultString;
+- (NSString *)resultString;
 
 @end
