@@ -56,6 +56,9 @@
 #define DEFAULT_PREF_KEY_ITUNES_INTEGRATION [NSNumber numberWithBool:NO]
 #define PREF_KEY_DOWNLOAD_DIR @"downloadDir"
 #define DEFAULT_PREF_KEY_DOWNLOAD_DIR @"~/Music/XNJB/"
+#define PREF_KEY_ITUNES_LOCATION @"iTunesLocation"
+#define DEFAULT_PREF_KEY_ITUNES_LOCATION @"~/Music/iTunes/iTunes Music Library.xml"
+
 // Notifications
 #define NOTIFICATION_CONNECTED @"XNJBConnected"
 #define NOTIFICATION_DISCONNECTED @"XNJBDisconnected"
