@@ -159,7 +159,7 @@ ptp_pack_string(PTPParams *params, char *string, unsigned char* data, uint16_t o
 		return;
 	}
 	
-	/* number of characters + leading 0 */
+	/* number of characters including terminating 0 (PTP standard confirmed) */
 	htod8a(&data[offset],packedlen+1);
 	for (i=0;i<packedlen && i< PTP_MAXSTRLEN; i++) {
 		htod16a(&data[offset+i*2+1],ucs2str[i]);
@@ -558,6 +558,28 @@ ptp_unpack_DPV (
 	case PTP_DTC_UINT32:
 		CTVAL(value->u32,dtoh32a);
 		break;
+
+
+
+	case PTP_DTC_UINT64:
+		*offset += 8;
+		/*fprintf(stderr,"unhandled unpack of uint64\n");*/
+		break;
+	case PTP_DTC_INT64:
+		*offset += 8;
+		/*fprintf(stderr,"unhandled unpack of int64\n");*/
+		break;
+	case PTP_DTC_UINT128:
+		*offset += 16;
+		/*fprintf(stderr,"unhandled unpack of uint128n");*/
+		break;
+	case PTP_DTC_INT128:
+		*offset += 16;
+		/*fprintf(stderr,"unhandled unpack of int128n");*/
+		break;
+
+
+
 	case PTP_DTC_AINT8:
 		RARR(value,i8,dtoh8a);
 		break;
@@ -587,6 +609,8 @@ ptp_unpack_DPV (
 			return 0;
 		break;
 	}
+	default:
+		return 0;
 	}
 	return 1;
 }
